[−][src]Crate mpris
mpris
mpris is an idiomatic library for dealing with MPRIS2-compatible media players over D-Bus.
This would mostly apply to the Linux-ecosystem which is a heavy user of D-Bus.
Getting started
Some hints on how to use this library:
- Look at the examples under
examples/. - Look at the
PlayerFinderstruct.
Structs
| DBusError | Something went wrong when communicating with the D-Bus. This could either be an underlying D-Bus library problem, or that the other side did not conform to the expected protocols. |
| InvalidLoopStatus |
|
| InvalidPlaybackStatus |
|
| Metadata | A structured representation of the |
| Player | A MPRIS-compatible player. |
| PlayerFinder | Used to find |
| Progress | Struct containing information about current progress of a Player. |
| ProgressTracker | Controller for calculating Progress for a given Player. |
| TrackID | Represents the MPRIS |
Enums
| Event | Represents a change in Player state. |
| FindingError | This enum encodes possible error cases that could happen when finding players. |
| LoopStatus | A Player's looping status. |
| MetadataValue | Holds a dynamically-typed metadata value. |
| MetadataValueKind | |
| PlaybackStatus |